/*
 * CpuTime - Retrieving the user and the system time of the current process
 * Copyright (C) 2005  Johannes Mayer
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package de.uniulm.sai.util;

import java.util.*;
import java.io.*;
import java.lang.*;

/**
 * This class makes it possible to access the user and the system time
 * of the current process (not thread!). These times are summed over
 * all processes and also include time consumed by the JVM (e.g. for
 * garbage collection).
 *
 * @author  Johannes Mayer
 * @version 0.9, 2005-12-20
 */
public class CpuTime {
    static {
	// load the native library
        System.loadLibrary("cputime");
	// retrieve the number of ticks per second
	TICKS_PER_SECOND = _ticksPerSecond();
    }

    /** Contains the number of ticks per second. */
    private static final int TICKS_PER_SECOND;

    /**
     * Returns the number of ticks per second which is
     * necessary to convert the result of the other
     * native methods into the unit seconds.
     */
    private static native int _ticksPerSecond();

    /** Returns the user time of the current process in ticks. */
    private static native long _userTime();
    /** Returns the system time of the current process in ticks. */
    private static native long _sysTime();
    /** Returns the sum of the user and system times of the current process in ticks. */
    private static native long _userSysTime();

    /**
     * Returns the user time of the current process in seconds.
     * @return	the user time of the current process in seconds.
     */
    public static double getUserTime() {
        return (double) _userTime() / (double) TICKS_PER_SECOND;
    }
    /**
     * Returns the system time of the current process in seconds.
     * @return	the system time of the current process in seconds.
     */
    public static double getSystemTime() {
        return (double) _sysTime() / (double) TICKS_PER_SECOND;
    }
    /**
     * Returns the sum of the user and system times of the current process in seconds.
     * @return	the sum of the user and system times of the current process in seconds.
     */
    public static double getTotalTime() {
        return (double) _userSysTime() / (double) TICKS_PER_SECOND;
    }

    /** Do not allow instances of this utility class. */
    private CpuTime() {
    }
}
